@@ -229,7 +229,7 @@ class KalturaIE(InfoExtractor):
     def _real_extract(self, url):
         url, smuggled_data = unsmuggle_url(url, {})
 
-        mobj = re.match(self._VALID_URL, url)
+        mobj = self._match_valid_url(url)
         partner_id, entry_id = mobj.group('partner_id', 'id')
         ks = None
         captions = None
