@@ -5,10 +5,8 @@ import re
 
 from .turner import TurnerBaseIE
 from ..compat import (
-    compat_parse_qs,
     compat_str,
     compat_urllib_parse_unquote,
-    compat_urllib_parse_urlparse,
 )
 from ..utils import (
     int_or_none,
@@ -16,6 +14,7 @@ from ..utils import (
     OnDemandPagedList,
     parse_duration,
     parse_iso8601,
+    parse_qs,
     try_get,
     update_url_query,
     urljoin,
@@ -165,7 +164,7 @@ class NBAWatchIE(NBAWatchBaseIE):
 
     def _real_extract(self, url):
         display_id = self._match_id(url)
-        collection_id = compat_parse_qs(compat_urllib_parse_urlparse(url).query).get('collection', [None])[0]
+        collection_id = parse_qs(url).get('collection', [None])[0]
         if collection_id:
             if self.get_param('noplaylist'):
                 self.to_screen('Downloading just video %s because of --no-playlist' % display_id)
@@ -337,7 +336,7 @@ class NBABaseIE(NBACVPBaseIE):
         return info
 
     def _real_extract(self, url):
-        team, display_id = re.match(self._VALID_URL, url).groups()
+        team, display_id = self._match_valid_url(url).groups()
         if '/play#/' in url:
             display_id = compat_urllib_parse_unquote(display_id)
         else:
@@ -359,7 +358,7 @@ class NBAEmbedIE(NBABaseIE):
     }]
 
     def _real_extract(self, url):
-        qs = compat_parse_qs(compat_urllib_parse_urlparse(url).query)
+        qs = parse_qs(url)
         content_id = qs['contentId'][0]
         team = qs.get('team', [None])[0]
         if not team:
